@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2016 - 2021 -- Lars Heuer
+# Copyright (c) 2016 - 2022 -- Lars Heuer
 # All rights reserved.
 #
 # License: BSD License
@@ -238,7 +238,8 @@ def make_vcard_data(name, displayname, email=None, phone=None, fax=None,
                     videophone=None, memo=None, nickname=None, birthday=None,
                     url=None, pobox=None, street=None, city=None, region=None,
                     zipcode=None, country=None, org=None, lat=None, lng=None,
-                    source=None, rev=None, title=None, photo_uri=None):
+                    source=None, rev=None, title=None, photo_uri=None,
+                    cellphone=None, homephone=None, workphone=None):
     """\
     Creates a string encoding the contact information as vCard 3.0.
 
@@ -291,6 +292,12 @@ def make_vcard_data(name, displayname, email=None, phone=None, fax=None,
     :type title: str, iterable of strings, or None
     :param photo_uri: Photo URI. Multiple values are allowed.
     :type photo_uri: str, iterable of strings, or None
+    :param cellphone: Cell phone number. Multiple values are allowed.
+    :type cellphone: str, iterable of strings, or None
+    :param homephone: Home phone number. Multiple values are allowed.
+    :type homephone: str, iterable of strings, or None
+    :param workphone: Work phone number. Multiple values are allowed.
+    :type workphone: str, iterable of strings, or None
     :rtype: str
     """
     def make_multifield(name, val):
@@ -310,6 +317,9 @@ def make_vcard_data(name, displayname, email=None, phone=None, fax=None,
     data.extend(make_multifield('TEL', phone))
     data.extend(make_multifield('TEL;TYPE=FAX', fax))
     data.extend(make_multifield('TEL;TYPE=VIDEO', videophone))
+    data.extend(make_multifield('TEL;TYPE=CELL', cellphone))
+    data.extend(make_multifield('TEL;TYPE=HOME', homephone))
+    data.extend(make_multifield('TEL;TYPE=WORK', workphone))
     data.extend(make_multifield('URL', url))
     data.extend(make_multifield('TITLE', title))
     data.extend(make_multifield('PHOTO;VALUE=uri', photo_uri))
@@ -352,7 +362,8 @@ def make_vcard(name, displayname, email=None, phone=None, fax=None,
                videophone=None, memo=None, nickname=None, birthday=None,
                url=None, pobox=None, street=None, city=None, region=None,
                zipcode=None, country=None, org=None, lat=None, lng=None,
-               source=None, rev=None, title=None, photo_uri=None):
+               source=None, rev=None, title=None, photo_uri=None,
+               cellphone=None, homephone=None, workphone=None):
     """\
     Creates a QR code which encodes a `vCard <https://en.wikipedia.org/wiki/VCard>`_
     version 3.0.
@@ -406,6 +417,12 @@ def make_vcard(name, displayname, email=None, phone=None, fax=None,
     :type title: str, iterable of strings, or None
     :param photo_uri: Photo URI. Multiple values are allowed.
     :type photo_uri: str, iterable of strings, or None
+    :param cellphone: Cell phone number. Multiple values are allowed.
+    :type cellphone: str, iterable of strings, or None
+    :param homephone: Home phone number. Multiple values are allowed.
+    :type homephone: str, iterable of strings, or None
+    :param workphone: Work phone number. Multiple values are allowed.
+    :type workphone: str, iterable of strings, or None
     :rtype: segno.QRCode
     """
     return segno.make_qr(make_vcard_data(name, displayname, email=email,
@@ -417,7 +434,10 @@ def make_vcard(name, displayname, email=None, phone=None, fax=None,
                                          zipcode=zipcode, country=country,
                                          org=org, lat=lat, lng=lng,
                                          source=source, rev=rev, title=title,
-                                         photo_uri=photo_uri))
+                                         photo_uri=photo_uri,
+                                         cellphone=cellphone,
+                                         homephone=homephone,
+                                         workphone=workphone))
 
 
 def make_geo_data(lat, lng):
